@@ -9,9 +9,7 @@
  *
  */
 
-#define _GNU_SOURCE
-#define _LARGEFILE64_SOURCE
-
+#include "config.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -53,6 +51,9 @@ static char do_decrypt;
 #define do_decrypt 0
 #endif
 static char splash_param;
+#ifdef CONFIG_FBSPLASH
+char fbsplash_theme[MAX_STR_LEN] = "";
+#endif
 static int use_platform_suspend;
 
 static struct splash splash;
@@ -130,6 +131,14 @@ static struct config_par parameters[] = {
 		.fmt = "%s",
 		.ptr = NULL,
 	},
+#ifdef CONFIG_FBSPLASH
+	{
+		.name = "fbsplash theme",
+		.fmt = "%s",
+		.ptr = fbsplash_theme,
+		.len = MAX_STR_LEN,
+	},
+#endif
 	{
 		.name = NULL,
 		.fmt = NULL,
@@ -158,7 +167,7 @@ static int read_area(int fd, void *buf, loff_t offset, unsigned int size)
 	if (!offset)
 		return 0;
 
-	if (lseek64(fd, offset, SEEK_SET) == offset)
+	if (lseek(fd, offset, SEEK_SET) == offset)
 		cnt = read(fd, buf, size);
 	if (cnt < (ssize_t)size)
 		res = cnt < 0 ? cnt : -EIO;
@@ -350,8 +359,12 @@ static int load_image(struct swap_map_handle *handle, int dev,
 	unsigned int m, n;
 	int ret;
 	int error = 0;
+	char message[SPLASH_GENERIC_MESSAGE_SIZE];
+
+	sprintf(message, "Loading image data pages (%u pages)...", nr_pages);
+	splash.set_caption(message);
+	printf("%s     ", message);
 
-	printf("Loading image data pages (%u pages) ...     ", nr_pages);
 	m = nr_pages / 100;
 	if (!m)
 		m = 1;
@@ -763,6 +776,10 @@ static inline int get_config(int argc, char *argv[])
 		       "help\0\t\t\tthis text",
 		       no_argument,		NULL, 'h'
 		   },
+		   {
+		       "version\0\t\t\tversion information",
+		       no_argument,		NULL, 'V'
+		   },
 		   {
 		       "config\0\t\talternative configuration file.",
 		       required_argument,	NULL, 'f'
@@ -783,7 +800,9 @@ static inline int get_config(int argc, char *argv[])
 	};
 	int i, error;
 	char *conf_name = CONFIG_FILE;
-	const char *optstring = "hf:o:r:P:";
+	const char *optstring = "hVf:o:r:P:";
+	struct stat stat_buf;
+	int fail_missing_config = 0;
 
 	/* parse only config file argument */
 	while ((i = getopt_long(argc, argv, optstring, options, NULL)) != -1) {
@@ -791,22 +810,34 @@ static inline int get_config(int argc, char *argv[])
 		case 'h':
 			usage(my_name, options, optstring);
 			exit(EXIT_SUCCESS);
+		case 'V':
+			version(my_name, NULL);
+			exit(EXIT_SUCCESS);
 		case 'f':
 			conf_name = optarg;
+			fail_missing_config = 1;
 			break;
 		}
 	}
 
-	error = parse(my_name, conf_name, parameters);
-	if (error) {
-		fprintf(stderr, "%s: Could not parse config file\n", my_name);
-		return error;
+	if (stat(conf_name, &stat_buf)) {
+		if (fail_missing_config) {
+			fprintf(stderr, "%s: Could not stat configuration file\n",
+				my_name);
+			return -ENOENT;
+		}
+	}
+	else {
+		error = parse(my_name, conf_name, parameters);
+		if (error) {
+			fprintf(stderr, "%s: Could not parse config file\n", my_name);
+			return error;
+		}
 	}
 
 	optind = 0;
 	while ((i = getopt_long(argc, argv, optstring, options, NULL)) != -1) {
 		switch (i) {
-		case 'h':
 		case 'f':
 			/* already handled */
 			break;
